# astroparse
# Parsing routines
# Jure Skvarc
import re
from sys import *

#  Transform a string to right ascension in arcseconds
def strtora(ras):
    try:
       (h, m, s) = re.search('([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}\.[0-9]*)', ras).groups()
    except:
       print "Error in strtora"
       exit()
    h = int(h)
    m = int(m)
    s = float(s)
    return 15 * (h * 3600.0 + m * 60.0 + s)


#  Transform a string to declination in arcseconds
def strtodec(decs):
    try:
       (sign, h, m, s) = re.search('([+|-]*)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}\.[0-9]*)', decs).groups()
    except:
       print "Error in strtodec"
       exit()
    h = int(h)
    m = int(m)
    s = float(s)
    if sign == '-':
        return -(h * 3600.0 + m * 60.0 + s)
    else:
        return (h * 3600.0 + m * 60.0 + s)

#  Format RA for printout
def format_ra_g(ra, sep):
    ra = ra / 15.0
    h = int(ra)
    ra = ra - h
    ra = ra * 60.0
    m = int(ra + 1e-9)
    s = (ra - m + 1e-9) * 60
    return '%02d%c%02d%c%05.2f' % (h, sep, m, sep, s)


#  Format declination for printout
def format_dec_g(dec, sep):

  if (dec < 0):
    c = '-'
    dec = -dec
  else:
    c = '+'
  d = int(dec)
  dec = dec - d
  dec = dec * 60.0
  m = int(dec + 1e-9)
  s = (dec - m + 1e-9) * 60
  return '%c%02d%c%02d%c%04.1f' % (c, d, sep, m, sep, s)


def format_ra(ra):
  return format_ra_g(ra, ':')

def format_dec(dec):
  return format_dec_g(dec, ':')


#  Format ra for MPC report 
def format_ra_mpc(ra):
  return format_ra_g(ra, ' ')


# Format declination for MPC report 
def format_dec_mpc(dec):
  return format_dec_g(dec, ' ')

