# astrotime.py
# Jure Skvarc
# Time related functions for astronomical calculations

#===========================================================================
#  Extract hour from the decimal day and output hours in hh:mm:ss.ss format
#===========================================================================
def tohours(day):
  day = day - int(day)
  hours = int(24 * day)
  day = 24 * day - hours
  minutes = int(60 * day)
  day = 60 * day - minutes
  seconds = 60 * day
  return "%02d:%02d:%05.2f" % (hours, minutes, seconds)


#  Calculate Julian Day for given year, month and fractional day
def julian(year, month, day):
  dm = [0, 32, 30, 32, 31, 32, 31, 32, 32, 31, 32, 31, 32]
  if year < -4712 or month < 1 or month > 12 or day < 0 or day >= dm[month]:
    return -1

  if year == 1582 and month == 10 and day >=5 and day < 15:
    return -1
  if month < 3:
    year = year - 1
    month = month + 12
  a = year / 100
  if year > 1582 or (year == 1582 and (month > 10 or \
    (month == 10 and day >= 15.0))):
    b = 2 - a + a / 4
  else:
    b = 0
  return int(365.25 * (year + 4716)) + int(30.6001 * (month + 1)) + day + b - 1524.5
  return day


#  Izracuna leto, mesec in decimalni dan iz julijanskega dneva
#  Po knjigi Meeus, str. 63
def date_from_julian(jd):

    jd = jd + 0.5
    z = int(jd)
    f = jd - z
    if z < 2299161:
	a = z
    else:
	alpha = int((z - 1867216.25) / 36524.25)
	a = z + 1 + alpha - int(alpha / 4)

    b = a + 1524
    c = int((b - 122.1) / 365.25)
    d = int(365.25 * c)
    e = int((b - d) / 30.6001)
    day = b - d - int(30.6001 * e) + f
    if e < 14:
	month = e - 1
    else:
	month = e - 13
    if month > 2:
	year = c - 4716
    else:
	year = c - 4715
    return (year, month, day)

#  Izracuna sidericni za dano longitudo in julijanski dan
def sidereal(jd, longitude):

  t = (jd - 2451545.0) / 36525.0
  #  sidereal time at ut in Greenwich
  sidereal = 280.46061837 + 360.98564736629 * (jd - 2451545.0) +\
    (0.000387933 - t / 38710000.0) * t * t
  sidereal = sidereal - longitude
  return sidereal % 360.0
