#  astrotrig.py
#  Astronomical trigonometry related functions
#  Jure Skvarc
from astroparse import *
from  math import *

#  Calculate the value of the haversine function
def hav(x):
  x = sin(0.5 * x)
  return x * x

#  Inverse haversine function
def invhav(x):
  return 2.0 * asin(sqrt(x))

#===================================================
#  Calculate the angular distance between two points
#===================================================
def angular_distance(ra1, dec1, ra2, dec2):
  return invhav(hav(dec1 - dec2) + cos(dec1) * cos(dec2) * hav(ra1 - ra2))
 


# Calculate the distance between two points. Use absolute norm
def absolute_distance(ra1, dec1, ra2, dec2):
    ra1 = strtora(ra1) * 4.84813681109e-6
    dec1 = strtodec(dec1) * 4.84813681109e-6
    ra2 = strtora(ra2) * 4.84813681109e-6
    dec2 = strtodec(dec2) * 4.84813681109e-6
    dra = abs(ra1 - ra2)
    if dra > pi:
	dra = 2 * pi - dra
    ddec = abs(dec1 - dec2)
    return dra + ddec



# Calculate the distance between two points. Use maximum norm
def maximum_distance(ra1, dec1, ra2, dec2):

    ra1 = strtora(ra1) * 4.84813681109e-6
    dec1 = strtodec(dec1) * 4.84813681109e-6
    ra2 = strtora(ra2) * 4.84813681109e-6
    dec2 = strtodec(dec2) * 4.84813681109e-6
    dra = abs(ra1 - ra2)
    if dra > pi:
	dra = 2 * pi - dra
    ddec = abs(dec1 - dec2)
    if ddec > dra:
	return ddec
    else:
	return dra

