#  astrotrig.py
#  Astronomical trigonometry related functions
#  Jure Skvarc
from astrotime import *
from astroparse import *
from  math import *

#  Calculate the value of the haversine function
def hav(x):
  x = sin(0.5 * x)
  return x * x

#  Inverse haversine function
def invhav(x):
  return 2.0 * asin(sqrt(x))

#===================================================
#  Calculate the angular distance between two points
#===================================================
def angular_distance(ra1, dec1, ra2, dec2):
  return invhav(hav(dec1 - dec2) + cos(dec1) * cos(dec2) * hav(ra1 - ra2))
 


# Calculate the distance between two points. Use absolute norm
def absolute_distance(ra1, dec1, ra2, dec2):
    ra1 = strtora(ra1) * 4.84813681109e-6
    dec1 = strtodec(dec1) * 4.84813681109e-6
    ra2 = strtora(ra2) * 4.84813681109e-6
    dec2 = strtodec(dec2) * 4.84813681109e-6
    dra = abs(ra1 - ra2)
    if dra > math.pi:
	dra = 2 * math.pi - dra
    ddec = abs(dec1 - dec2)
    return dra + ddec



# Calculate the distance between two points. Use maximum norm
def maximum_distance(ra1, dec1, ra2, dec2):

    ra1 = strtora(ra1) * 4.84813681109e-6
    dec1 = strtodec(dec1) * 4.84813681109e-6
    ra2 = strtora(ra2) * 4.84813681109e-6
    dec2 = strtodec(dec2) * 4.84813681109e-6
    dra = abs(ra1 - ra2)
    if dra > math.pi:
	dra = 2 * math.pi - dra
    ddec = abs(dec1 - dec2)
    if ddec > dra:
	return ddec
    else:
	return dra




DEGRAD = pi / 180.0
RADDEG = 1.0 / DEGRAD

def equtoaltaz(ra, dec, longitude, latitude, jd):

    #  Calculate local hour angle for ra
    sr = sidereal(jd, longitude) % 360.0
    if sr < 0:
        sr = 360 + sr
    ha = (sr - ra) % 360.0
    if ha < 0:
        ha = DEGRAD * (360 + ha)
    else:
        ha = DEGRAD * ha

    cha = cos(ha)
    fi = latitude * DEGRAD
    sfi = sin(fi)
    cfi = cos(fi)
    decl = dec * DEGRAD
    az = RADDEG * atan2(sin(ha), cha * sfi - tan(decl) * cfi)
    alt = RADDEG * asin(sfi * sin(decl) + cfi * cos(decl) * cha)
    return (alt, az)


# Calculate ra and dec from the given altitude and azimuth and location 
def altaztoequ(alt, az, longitude, latitude, jd):

    sr = sidereal(jd, longitude) % 360.0
    if sr < 0:
        sr = 360 + sr
    cha = cos(DEGRAD * az)
    fi = latitude * DEGRAD
    sfi = sin(fi)
    cfi = cos(fi);
    decl = alt * DEGRAD
    ra = RADDEG * atan2(sin(DEGRAD * az), cha * sfi + tan(decl) * cfi)
    #  Calculate local hour angle for ra
    ra = (sr - ra) % 360.0
    dec = RADDEG * asin(sfi * sin(decl) - cfi * cos(decl) * cha)
    return (ra, dec)
