#
# mpcstuff.py
# Knjiznica podprogramov, ki pridejo prav pri obdelavi stvari,
# povezanih z MPC

import re
from string import *
import astrotime
import astroparse

#===========================================================================
#  Pretvorba designacije v skrajsano (pakirano) designacijo
#===========================================================================

def designation_to_packed(name):
  packed = ''
  try:
    year, code = split(name)
  except:
      # Could not split, must be a number
      return name
  try:
      year = atoi(year)
  except:
      return name
  #  Does it look like a year? 
  if find(code, 'P-L') >= 0 or find(code, 'T-1') >= 0 or find(code, 'T-2') >= 0 or find(code, 'T-3') >= 0:
    packed = "%c%cS%4s" % (name[5], name[7], year)
  elif year > 1900 and  year < 2100:
    cent = chr(year / 100 - 19 + ord('J'))
    if  len(code[2:]) > 0:
      num = atoi(code[2:])
    else: 
      num = 0
    if num < 100:
      n1 = chr(num / 10 + ord('0'))
    else:
      n1 = chr(num / 10 - 10 + ord('A'))
    n2 = chr(num % 10 + ord('0'))
    packed = "%c%02d%c%c%c%c" % (cent, year % 100, code[0], n1, n2, code[1])
  return packed


#  Make a designation or a number out of a packed designation or a number
def make_designation(desig):

    fdes3 = desig[0:3]
    fdes = desig[0:1]
    if re.search('[I-K][0-9][0-9]', fdes3) != None:
        #  Convert from packed to full designation  
        year = 1900 + 100 * (ord(fdes) - ord('J')) + int(desig[1:3])
        code = desig[3] + desig[6]
        n1 = desig[4:5]
        if ord(n1) >= ord('A'):
            n = (ord(n1) - ord('A') + 10) * 10 + int(desig[5])
        else:
            n = int(n1) * 10 + int(desig[5])

        if n > 0:
            desig = '%s %s%d' % (year, code, n)
        else:
            desig = '%s %s' % (year, code)

    elif re.search('T[1-3]S', fdes3) or re.search('PLS', fdes3):
        desig = desig[3:7] + ' ' + fdes + '-' + desig[1:2]
    elif re.search('[0-9]{5}', desig) != None:
        desig = int(desig)

    return desig
            


#  Pretvori pakiran datum v datum oblike YYYYMMDD
def packed_to_date(date):
    if re.search('[I-K][0-9][0-9]', date) != None:
        year = 1900 + 100 * (ord(date[0]) - ord('J')) + int(date[1:3])
        month = date[3]
        if ord(month) > ord('9'):
            month = 10 + ord(month) - ord('A')
        else:
            month = int(month)
        day = date[4]
        if ord(day) > ord('9'):
            day = 10 + ord(day) - ord('A')
        else:
            day = int(day)
    return '%04d%02d%02d' % (year, month, day)



#  Naredi vrstico za MPC za dane parametre
def make_mpc_line(jd, ra, dec, mag, filter, obscode, desig):

  if mag != 0:
    ms = '%04.1f' % (mag)
  else:
    ms = ''
  year, month, day = astrotime.date_from_julian(jd)
  return '%s  C%04d %02d %08.5f %11s %11s          %4s %1s      %03d' % \
         (desig, year, month, day, astroparse.format_ra_mpc(ra),\
          astroparse.format_dec_mpc(dec), ms, filter, obscode)
