#  stars.py
#  Jure Skvarc, May 2000
#  Python module for reading star data from different catalogs
#  Data retrieving routines are implemented in C
#
import starcatalogs
#  Class Star is a container for data about individual stars
#    - star id (if available)
#    - Celestial and image coordinates
#    - UBVRI magnitudes, if available
#    - error estimates for all the above quantities
#  When the values are missing, -99 is read for any of number quantites
class Star:
    fmt = '%20s %10.6f %5.3f %10.6f %5.3f %7.2f %7.2f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f'
    def __init__(self):
        self.id = None
        self.ra = -99   # Right ascension in decimal degrees
        self.sra = -99  # RA error estimate in arcseconds
        self.dec = -99  # Declination in decimal degrees
        self.sdec = -99 # Dec error estimate in arcseconds
        self.x = -99    # Pixel x coordinate
        self.y = -99    # Pixel y coordinate
        self.u = -99    # U magnitude
        self.su = -99   # U magnitude uncertainty
        self.b = -99    # B magnitude
        self.sb = -99   # B magnitude uncertainty
        self.v = -99    # V magnitude
        self.sv = -99   # V magnitude uncertainty
        self.r = -99    # R magnitude
        self.sr = -99   # R magnitude uncertainty
        self.i = -99    # I magnitude
        self.si = -99   # I magnitude uncertainty

    def __str__(self):
        return self.fmt % (self.id, self.ra, self.sra, self.dec, self.sdec,\
                           self.x, self.y, self.u, self.su, self.b, self.sb,\
                           self.v, self.sv, self.r, self.sr, self.i, self.si)
    

#  Class Catalog contains the inteface to different star catalogs:
#    GSC, USNO, ACT and PHOTOM
class Catalog:
    def __init__(self, type, path):
        self.path = path
        self.type = type

    def get_stars(self, ra, dec, fi = 0.0, width=1, height=1, \
                  w=1024, h=1024, minmag=0, maxmag=22):
        list = starcatalogs.get_stars(self.type, self.path,\
                                      ra, dec, fi, width, height,\
                                      w, h, minmag, maxmag)
        stars = []
        for a in list:
            star = Star()
            star.id = a[0]
            star.ra = a[1]
            star.sra = a[2]
            star.dec = a[3]
            star.sdec = a[4]
            star.x = a[15]
            star.y = a[16]
            star.u = a[5]
            star.su = a[6]
            star.b = a[7]
            star.sb = a[8]
            star.v = a[9]
            star.sv = a[10]
            star.r = a[11]
            star.sr = a[12]
            star.i = a[13]
            star.si = a[14]
            stars.append(star)
        del list
        return stars

